@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT
+from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
@@ -50,7 +50,7 @@ class VirtualMachineImport(NamespacedResource):
         """
 
         VALIDATION_COMPLETED = "ValidationCompleted"
-        SECRET_NOT_FOUND = "SecretNotFound"  # pragma: allowlist secret
+        SECRET_NOT_FOUND = "SecretNotFound"
         RESOURCE_MAPPING_NOT_FOUND = "ResourceMappingNotFound"
         UNINITIALIZED_PROVIDER = "UninitializedProvider"
         SOURCE_VM_NOT_FOUND = "SourceVMNotFound"
@@ -109,6 +109,8 @@ class VirtualMachineImport(NamespacedResource):
         finalize_date=None,
         privileged_client=None,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -117,6 +119,8 @@ class VirtualMachineImport(NamespacedResource):
             teardown=teardown,
             privileged_client=privileged_client,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.vm_id = vm_id
         self.vm_name = vm_name
@@ -276,6 +280,7 @@ class ResourceMapping(NamespacedResource):
         client=None,
         teardown=True,
         yaml_file=None,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -283,6 +288,7 @@ class ResourceMapping(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            **kwargs,
         )
         self.mapping = mapping
 
