@@ -1,13 +1,16 @@
 # -*- coding: utf-8 -*-
 
-from openshift.dynamic.exceptions import ResourceNotFoundError
 
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
-from ocp_resources.resource import TIMEOUT, NamespacedResource
+from ocp_resources.logger import get_logger
+from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class VirtualMachineRestore(NamespacedResource):
     """
     VirtualMachineRestore object.
@@ -24,6 +27,8 @@ class VirtualMachineRestore(NamespacedResource):
         client=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -31,6 +36,8 @@ class VirtualMachineRestore(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.vm_name = vm_name
         self.snapshot_name = snapshot_name
@@ -49,7 +56,7 @@ class VirtualMachineRestore(NamespacedResource):
         spec["virtualMachineSnapshotName"] = self.snapshot_name
         return res
 
-    def wait_complete(self, status=True, timeout=TIMEOUT):
+    def wait_complete(self, status=True, timeout=TIMEOUT_4MINUTES):
         """
         Wait for VirtualMachineRestore to be in status complete
 
@@ -60,7 +67,7 @@ class VirtualMachineRestore(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        self.logger.info(
+        LOGGER.info(
             f"Wait for {self.kind} {self.name} status to be complete = {status}"
         )
 
@@ -74,26 +81,3 @@ class VirtualMachineRestore(NamespacedResource):
         for sample in samples:
             if sample:
                 return
-
-    def wait_restore_done(self, timeout=TIMEOUT_4MINUTES):
-        """
-        Wait for the the restore to be done. This check 2 parameters, the restore status to be complete
-        and the VM status restoreInProgress to be None.
-
-        Args:
-            timeout (int): Time to wait.
-
-        Raises:
-            TimeoutExpiredError: If timeout reached.
-        """
-        self.wait_complete(timeout=timeout)
-
-        vm = VirtualMachine(
-            client=self.client,
-            namespace=self.namespace,
-            name=self.vm_name,
-        )
-
-        if vm.exists:
-            return vm.wait_for_status_none(status="restoreInProgress", timeout=timeout)
-        raise ResourceNotFoundError(f"VirtualMachine: {vm.name} not found")
