@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 
-
-from openshift.dynamic.exceptions import ResourceNotFoundError
-
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
-from ocp_resources.resource import TIMEOUT, NamespacedResource
+from ocp_resources.logger import get_logger
+from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class VirtualMachineSnapshot(NamespacedResource):
     """
     VirtualMachineSnapshot object.
@@ -24,6 +25,8 @@ class VirtualMachineSnapshot(NamespacedResource):
         client=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -31,6 +34,8 @@ class VirtualMachineSnapshot(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.vm_name = vm_name
 
@@ -47,7 +52,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         spec["source"]["name"] = self.vm_name
         return res
 
-    def wait_ready_to_use(self, status=True, timeout=TIMEOUT):
+    def wait_ready_to_use(self, status=True, timeout=TIMEOUT_4MINUTES):
         """
         Wait for VirtualMachineSnapshot to be in readyToUse status
 
@@ -58,7 +63,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        self.logger.info(
+        LOGGER.info(
             f"Wait for {self.kind} {self.name} status to be {'' if status else 'not '}ready to use"
         )
 
@@ -72,26 +77,3 @@ class VirtualMachineSnapshot(NamespacedResource):
         for sample in samples:
             if sample:
                 return
-
-    def wait_snapshot_done(self, timeout=TIMEOUT_4MINUTES):
-        """
-        Wait for the the snapshot to be done. This check 2 parameters, the snapshot status to be readyToUse
-        and the VM status snapshotInProgress to be None.
-
-        Args:
-            timeout (int): Time to wait.
-
-        Raises:
-            TimeoutExpiredError: If timeout reached.
-        """
-        self.wait_ready_to_use(timeout=timeout)
-
-        vm = VirtualMachine(
-            client=self.client,
-            namespace=self.namespace,
-            name=self.vm_name,
-        )
-
-        if vm.exists:
-            return vm.wait_for_status_none(status="snapshotInProgress", timeout=timeout)
-        raise ResourceNotFoundError(f"VirtualMachine: {vm.name} not found")
